@@ -30,9 +30,9 @@ build_options+=('lto')
 buildenv_functions+=('buildenv_lto')
 
 buildenv_lto() {
-	if check_option "lto" "y"; then
-		CFLAGS+=" -flto"
-		CXXFLAGS+=" -flto"
-		LDFLAGS+=" -flto"
+	if check_option "lto" "y" && ! check_option "buildflags" "n"; then
+		CFLAGS+=" ${LTOFLAGS:--flto}"
+		CXXFLAGS+=" ${LTOFLAGS:--flto}"
+		LDFLAGS+=" ${LTOFLAGS:--flto}"
 	fi
 }
